@@ -3,20 +3,14 @@
 #ifndef __LHDMOD_H__
 #define __LHDMOD_H__
 
-double grad(int n, double *x, int *o, 
-			double vxsum, double vxz,
-            double a, double *e, double *v);
-double curve(int n, double *x, int *o, double xm,  
-          double *v, double vsum, double *vxm);
 double intercept(int n, double *e, double *v, double *z, double vsum);
-
 double sse(int n, double a, double *e, double *y, double *v);
 double bin_nllhd(int n, double a, double *e, double *y, double *v);
 double po_nllhd(int n, double a, double *e, double *y, double *v);
 
 double bin_reweight(int n, double a, double *e, 
-					double *y, double *v, double *z);
+					double *y, double *v, double *z, int *vzf);
 double po_reweight(int n, double a, double *e, 
-					double *y, double *v, double *z);
+					double *y, double *v, double *z, int *vzf);
 
 #endif
